@@ -1,20 +1,25 @@
 #!/usr/bin/env python
-import os, time, re
+from __future__ import absolute_import
+import os
+import time
+import re
 from functools import partial
-from flask import Flask, Module, url_for, render_template, request, session, redirect, g, make_response, current_app
-from decorators import login_required, guest_or_login_required, with_lock
-from decorators import global_lock
+from flask import Flask, Blueprint, url_for, request, session, redirect, g, make_response, current_app, render_template
+from .decorators import login_required, guest_or_login_required, with_lock
+from .decorators import global_lock
+# Make flask use the old session foo from <=flask-0.9
+from flask_oldsessions import OldSecureCookieSessionInterface
 
 from flask.ext.autoindex import AutoIndex
-try:
-    from sage.env import SAGE_SRC
-except ImportError:
-    SAGE_SRC = os.environ.get('SAGE_SRC', os.path.join(os.environ['SAGE_ROOT'], 'devel', 'sage'))
+from sage.env import SAGE_SRC, SAGE_DOC
 SRC = os.path.join(SAGE_SRC, 'sage')
 from flask.ext.openid import OpenID
-from flask.ext.babel import Babel, gettext, ngettext, lazy_gettext, get_locale
-from sagenb.misc.misc import SAGENB_ROOT, DATA, SAGE_DOC, translations_path
-
+from flask_babel import Babel, gettext, ngettext, lazy_gettext, get_locale
+from sagenb.misc.misc import SAGENB_ROOT, DATA, translations_path, N_, nN_, unicode_str
+from json import dumps
+from sagenb.notebook.cell import number_of_rows
+from sagenb.notebook.template import (css_escape, clean_name,
+                                      prettify_time_ago, TEMPLATE_PATH)
 oid = OpenID()
 
 class SageNBFlask(Flask):
@@ -23,6 +28,7 @@ class SageNBFlask(Flask):
     def __init__(self, *args, **kwds):
         self.startup_token = kwds.pop('startup_token', None)
         Flask.__init__(self, *args, **kwds)
+        self.session_interface = OldSecureCookieSessionInterface()
 
         self.config['SESSION_COOKIE_HTTPONLY'] = False
 
@@ -33,7 +39,13 @@ class SageNBFlask(Flask):
         self.add_static_path('/javascript', DATA)
         self.add_static_path('/static', DATA)
         self.add_static_path('/java', DATA)
-        self.add_static_path('/java/jmol', os.path.join(os.environ["SAGE_ROOT"],"local","share","jmol"))
+        self.add_static_path('/java/jmol', os.path.join(os.environ["SAGE_SHARE"],"jmol"))
+        self.add_static_path('/jsmol', os.path.join(os.environ["SAGE_SHARE"],"jsmol"))
+        self.add_static_path('/jsmol/js', os.path.join(os.environ["SAGE_SHARE"],"jsmol","js"))
+        self.add_static_path('/j2s', os.path.join(os.environ["SAGE_SHARE"],"jsmol","j2s"))
+        self.add_static_path('/jsmol/j2s', os.path.join(os.environ["SAGE_SHARE"],"jsmol","j2s"))
+        self.add_static_path('/j2s/core', os.path.join(os.environ["SAGE_SHARE"],"jsmol","j2s","core"))
+        self.add_static_path('/threejs', os.path.join(os.environ["SAGE_SHARE"],"threejs"))
         import mimetypes
         mimetypes.add_type('text/plain','.jmol')
 
@@ -42,15 +54,21 @@ class SageNBFlask(Flask):
         # Doc #
         #######
         #These "should" be in doc.py
-        DOC = os.path.join(SAGE_DOC, 'output', 'html', 'en')
-        self.add_static_path('/pdf', os.path.join(SAGE_DOC, 'output', 'pdf'))
+        DOC = os.path.join(SAGE_DOC, 'html', 'en')
+        self.add_static_path('/pdf', os.path.join(SAGE_DOC, 'pdf'))
         self.add_static_path('/doc/static', DOC)
-        #self.add_static_path('/doc/static/reference', os.path.join(SAGE_DOC, 'reference'))
 
-    def create_jinja_environment(self):
-        from sagenb.notebook.template import env
-        env.globals.update(url_for=url_for)
-        return env
+        # Template globals
+        self.add_template_global(url_for)
+        # Template filters
+        self.add_template_filter(css_escape)
+        self.add_template_filter(number_of_rows)
+        self.add_template_filter(clean_name)
+        self.add_template_filter(prettify_time_ago)
+        self.add_template_filter(max)
+        self.add_template_filter(lambda x: repr(unicode_str(x))[1:],
+                                 name='repr_str')
+        self.add_template_filter(dumps, 'tojson')
 
     def static_view_func(self, root_path, filename):
         from flask.helpers import send_from_directory
@@ -62,13 +80,14 @@ class SageNBFlask(Flask):
                           view_func=partial(self.static_view_func, root_path))
 
     def message(self, msg, cont='/', username=None, **kwds):
+        from sagenb.misc.misc import SAGE_VERSION
         """Returns an error message to the user."""
-        template_dict = {'msg': msg, 'cont': cont, 'username': username}
+        template_dict = {'msg': msg, 'cont': cont, 'username': username, 'sage_version': SAGE_VERSION}
         template_dict.update(kwds)
         return render_template(os.path.join('html', 'error_message.html'),
                                **template_dict)
 
-base = Module('sagenb.flask_version.base')
+base = Blueprint('base', 'sagenb.flask_version.base')
 
 #############
 # Main Page #
@@ -89,7 +108,7 @@ def index():
         response.set_cookie('cookie_test_%s'%g.notebook.port, expires=1)
         return response
 
-    from authentication import login
+    from .authentication import login
 
     if current_app.startup_token is not None and 'startup_token' in request.args:
         if request.args['startup_token'] == current_app.startup_token:
@@ -123,7 +142,7 @@ def localization_js():
     global _localization_cache
     locale=repr(get_locale())
     if _localization_cache.get(locale,None) is None:
-        data= render_template(os.path.join('js/localization.js'))
+        data = render_template(os.path.join('js/localization.js'), N_=N_, nN_=nN_)
         _localization_cache[locale] = (data, sha1(repr(data)).hexdigest())
     data,datahash = _localization_cache[locale]
 
@@ -188,7 +207,8 @@ def main_css():
 @login_required
 def help():
     from sagenb.notebook.tutorial import notebook_help
-    return render_template(os.path.join('html', 'docs.html'), username = g.username, notebook_help = notebook_help)
+    from sagenb.misc.misc import SAGE_VERSION
+    return render_template(os.path.join('html', 'docs.html'), username = g.username, notebook_help = notebook_help, sage_version=SAGE_VERSION)
 
 ###########
 # History #
@@ -203,7 +223,7 @@ def history():
 @login_required
 def live_history():
     W = g.notebook.create_new_worksheet_from_history(gettext('Log'), g.username, 100)
-    from worksheet import url_for_worksheet
+    from .worksheet import url_for_worksheet
     return redirect(url_for_worksheet(W))
 
 ###########
@@ -238,7 +258,7 @@ def create_or_login(resp):
         username = g.notebook.user_manager().get_username_from_openid(resp.identity_url)
         session['username'] = g.username = username
         session.modified = True
-    except KeyError:
+    except (KeyError, LookupError):
         session['openid_response'] = resp
         session.modified = True
         return redirect(url_for('set_profiles'))
@@ -298,26 +318,26 @@ def set_profiles():
                         parse_dict['challenge_html'] = chal.html(error_code = err_code)
                     else:
                         parse_dict['challenge_invalid'] = True
-                    raise ValueError
+                    raise ValueError("Invalid challenge")
                 else:
                     parse_dict['challenge_missing'] = True
-                    raise ValueError
+                    raise ValueError("Missing challenge")
 
             if not is_valid_username(username):
                 parse_dict['username_invalid'] = True
-                raise ValueError
+                raise ValueError("Invalid username")
             if g.notebook.user_manager().user_exists(username):
                 parse_dict['username_taken'] = True
-                raise ValueError
+                raise ValueError("Pre-existing username")
             if not is_valid_email(request.form.get('email')):
                 parse_dict['email_invalid'] = True
-                raise ValueError
+                raise ValueError("Invalid email")
             try:
                 new_user = User(username, '', email = resp.email, account_type='user')
                 g.notebook.user_manager().add_user_object(new_user)
-            except ValueError:
+            except ValueError as msg:
                 parse_dict['creation_error'] = True
-                raise ValueError
+                raise ValueError("Error in creating user\n%s"%msg)
             g.notebook.user_manager().create_new_openid(resp.identity_url, username)
             session['username'] = g.username = username
             session.modified = True
@@ -325,7 +345,6 @@ def set_profiles():
             return render_template('html/accounts/openid_profile.html', **parse_dict)
         return redirect(url_for('base.index'))
 
-
 #############
 # OLD STUFF #
 #############
@@ -401,7 +420,8 @@ def create_app(path_to_notebook, *args, **kwds):
     ##############
     # Create app #
     ##############
-    app = SageNBFlask('flask_version', startup_token=startup_token)
+    app = SageNBFlask('flask_version', startup_token=startup_token,
+                      template_folder=TEMPLATE_PATH)
     app.secret_key = os.urandom(24)
     oid.init_app(app)
     app.debug = True
@@ -413,33 +433,55 @@ def create_app(path_to_notebook, *args, **kwds):
     ####################################
     # create Babel translation manager #
     ####################################
-    babel = Babel(app, default_locale=notebook.conf()['default_language'],
-                  default_timezone='UTC',
-                  date_formats=None, configure_jinja=True)
+    babel = Babel(app, default_locale='en_US')
+
+    #Check if saved default language exists. If not fallback to default
+    @app.before_first_request
+    def check_default_lang():
+        def_lang = notebook.conf()['default_language']
+        trans_ids = [str(trans) for trans in babel.list_translations()]
+        if def_lang not in trans_ids:
+            notebook.conf()['default_language'] = None
+
+    #register callback function for locale selection
+    #this function must be modified to add per user language support
+    @babel.localeselector
+    def get_locale():
+        return g.notebook.conf()['default_language']
 
     ########################
     # Register the modules #
     ########################
     app.register_blueprint(base)
 
-    from worksheet_listing import worksheet_listing
+    from .worksheet_listing import worksheet_listing
     app.register_blueprint(worksheet_listing)
 
-    from admin import admin
+    from .admin import admin
     app.register_blueprint(admin)
 
-    from authentication import authentication
+    from .authentication import authentication
     app.register_blueprint(authentication)
 
-    from doc import doc
+    from .doc import doc
     app.register_blueprint(doc)
 
-    from worksheet import ws as worksheet
+    from .worksheet import ws as worksheet
     app.register_blueprint(worksheet)
 
-    from settings import settings
+    from .settings import settings
     app.register_blueprint(settings)
 
+    # Handles all uncaught exceptions by sending an e-mail to the
+    # administrator(s) and displaying an error page.
+    @app.errorhandler(Exception)
+    def log_exception(error):
+        from sagenb.notebook.notification import logger
+        logger.exception(error)
+        return app.message(
+            gettext('''500: Internal server error.'''),
+            username=getattr(g, 'username', 'guest')), 500
+
     #autoindex v0.3 doesnt seem to work with modules
     #routing with app directly does the trick
     #TODO: Check to see if autoindex 0.4 works with modules
